###########################################################################
#
#    Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#    Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.3 $

__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.Folder
import base_item


try:
  from Products.ZBabel.Utils import translate
except:
  from NoBabelTag import translate

methods = { 'translate': translate }


manage_add_news_form = HTMLFile('news_add', globals())

def manage_add_news(self, title, short_body, body, priority, public,
                   REQUEST=None):
    "Add an instance of the news class"
    new_id = self.get_unique_id()
    self._setObject(new_id, news(new_id, title, short_body, body, priority, public))
    if REQUEST is not None:
        REQUEST.RESPONSE.redirect(self.absolute_url())


class news(
    OFS.Folder.Folder,
    Persistent,
    Acquisition.Implicit,
    AccessControl.Role.RoleManager,
    base_item.base_item
    ):
    "Documentation string"

    meta_type = 'News'
    icon = 'misc_/NewsFolder/Folder_icon.gif'

    _properties = (
        {'id':'title', 'type':'string'},
        {'id':'short_body', 'type':'text'},
        {'id':'body', 'type':'text'},
        {'id':'priority', 'type':'int'},
        {'id':'published_via_email', 'type':'boolean'},
        {'id':'public', 'type':'boolean'}
        )

    __ac_permissions__ = (
        ('View management screens',
         ('manage_tabs', 'manage_main')),
        ('Change Permissions',
         ('manage_access',)),
        ('View News',
         ('', 'render_priority')),
        )

    index_html = HTMLFile('news_index', globals())

    priorities = {
        0: translate ( None, 'Low'),
        1: translate ( None, 'Medium'),
        2: translate ( None, 'High') }

    base_edit = HTMLFile('news_edit', globals())

    def __init__(self, id, title='', short_body='', body='', priority='',
                 public=None):
        "Initialize the class instance"
        self.id = id
        self.title = title
        self.short_body = short_body
        self.body = body
        self.priority = priority
        self.public = public
        if public:
            # Set viewable by anyone.
            # FIXME
            pass
        self.published_via_email = 0

    def render_priority(self):
        """Renders the priority."""
        return self.priorities[self.priority]

default__class_init__(news)

